@@ -3,7 +3,7 @@ package alerter
 import (
 	"fmt"
 
-	"github.com/cloudskiff/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource"
 )
 
 type AlerterInterface interface {
