@@ -9,8 +9,8 @@ import (
 
 	"github.com/r3labs/diff/v2"
 
-	"github.com/cloudskiff/driftctl/pkg/alerter"
-	"github.com/cloudskiff/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/alerter"
+	"github.com/snyk/driftctl/pkg/resource"
 )
 
 type Change struct {
@@ -74,7 +74,14 @@ type GenDriftIgnoreOptions struct {
 }
 
 func NewAnalysis(options AnalyzerOptions) *Analysis {
-	return &Analysis{options: options}
+	return &Analysis{
+		unmanaged:   []*resource.Resource{},
+		managed:     []*resource.Resource{},
+		deleted:     []*resource.Resource{},
+		differences: []Difference{},
+		alerts:      alerter.Alerts{},
+		options:     options,
+	}
 }
 
 func (a Analysis) MarshalJSON() ([]byte, error) {
