@@ -6,9 +6,9 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/config"
-	"github.com/cloudskiff/driftctl/test"
-	"github.com/cloudskiff/driftctl/test/mocks"
+	"github.com/snyk/driftctl/pkg/config"
+	"github.com/snyk/driftctl/test"
+	"github.com/snyk/driftctl/test/mocks"
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
 )
@@ -82,7 +82,7 @@ func TestDriftctlCmd_Scan(t *testing.T) {
 			env: map[string]string{
 				"DCTL_FROM": "test",
 			},
-			err: fmt.Errorf("Unable to parse from flag 'test': \nAccepted schemes are: tfstate://,tfstate+s3://,tfstate+http://,tfstate+https://,tfstate+tfcloud://"),
+			err: fmt.Errorf("Unable to parse from flag 'test': \nAccepted schemes are: tfstate://,tfstate+s3://,tfstate+http://,tfstate+https://,tfstate+tfcloud://,tfstate+gs://"),
 		},
 		{
 			env: map[string]string{
