@@ -7,26 +7,26 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/filter"
-	"github.com/cloudskiff/driftctl/pkg/output"
-	"github.com/cloudskiff/driftctl/pkg/remote/azurerm"
-	"github.com/cloudskiff/driftctl/pkg/remote/google"
-	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
-	resourceazure "github.com/cloudskiff/driftctl/pkg/resource/azurerm"
-	resourcegithub "github.com/cloudskiff/driftctl/pkg/resource/github"
-	resourcegoogle "github.com/cloudskiff/driftctl/pkg/resource/google"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
-	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
 	"github.com/pkg/errors"
+	"github.com/snyk/driftctl/pkg/filter"
+	"github.com/snyk/driftctl/pkg/output"
+	"github.com/snyk/driftctl/pkg/remote/azurerm"
+	"github.com/snyk/driftctl/pkg/remote/google"
+	resourceaws "github.com/snyk/driftctl/pkg/resource/aws"
+	resourceazure "github.com/snyk/driftctl/pkg/resource/azurerm"
+	resourcegithub "github.com/snyk/driftctl/pkg/resource/github"
+	resourcegoogle "github.com/snyk/driftctl/pkg/resource/google"
+	testresource "github.com/snyk/driftctl/test/resource"
+	terraform2 "github.com/snyk/driftctl/test/terraform"
 	"github.com/stretchr/testify/assert"
 
-	"github.com/cloudskiff/driftctl/pkg/iac/config"
-	"github.com/cloudskiff/driftctl/pkg/remote/aws"
-	"github.com/cloudskiff/driftctl/pkg/remote/github"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	"github.com/cloudskiff/driftctl/pkg/terraform"
-	"github.com/cloudskiff/driftctl/test/goldenfile"
-	"github.com/cloudskiff/driftctl/test/mocks"
+	"github.com/snyk/driftctl/pkg/iac/config"
+	"github.com/snyk/driftctl/pkg/remote/aws"
+	"github.com/snyk/driftctl/pkg/remote/github"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/test/goldenfile"
+	"github.com/snyk/driftctl/test/mocks"
 
 	"github.com/r3labs/diff/v2"
 )
@@ -160,6 +160,7 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Api Gateway domain name", dirName: "api_gateway_domain_name", wantErr: false},
 		{name: "Api Gateway vpc link", dirName: "api_gateway_vpc_link", wantErr: false},
 		{name: "Api Gateway V2 Api", dirName: "apigatewayv2_api", wantErr: false},
+		{name: "Api Gateway V2 Route", dirName: "apigatewayv2_route", wantErr: false},
 		{name: "Api Gateway request validator", dirName: "api_gateway_request_validator", wantErr: false},
 		{name: "Api Gateway rest api policy", dirName: "api_gateway_rest_api_policy", wantErr: false},
 		{name: "Api Gateway base path mapping", dirName: "api_gateway_base_path_mapping", wantErr: false},
@@ -170,12 +171,16 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Api Gateway method settings", dirName: "api_gateway_method_settings", wantErr: false},
 		{name: "Api Gateway integration", dirName: "api_gateway_integration", wantErr: false},
 		{name: "Api Gateway integration response", dirName: "api_gateway_integration_response", wantErr: false},
+		{name: "Api Gateway V2 authorizer", dirName: "aws_apigatewayv2_authorizer", wantErr: false},
 		{name: "AppAutoScaling Targets", dirName: "aws_appautoscaling_target", wantErr: false},
 		{name: "network acl", dirName: "aws_network_acl", wantErr: false},
 		{name: "network acl rule", dirName: "aws_network_acl_rule", wantErr: false},
 		{name: "default network acl", dirName: "aws_default_network_acl", wantErr: false},
 		{name: "App autoscaling policy", dirName: "aws_appautoscaling_policy", wantErr: false},
 		{name: "App autoscaling scheduled action", dirName: "aws_appautoscaling_scheduled_action", wantErr: false},
+		{name: "App gateway v2 vpc link", dirName: "apigatewayv2_vpc_link", wantErr: false},
+		{name: "Launch template", dirName: "aws_launch_template", wantErr: false},
+		{name: "Launch configuration", dirName: "aws_launch_configuration", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -360,6 +365,7 @@ func TestTerraformStateReader_Google_Resources(t *testing.T) {
 		{name: "sql database instance", dirName: "google_sql_database_instance", wantErr: false},
 		{name: "health check", dirName: "google_compute_health_check", wantErr: false},
 		{name: "cloudrun service", dirName: "google_cloudrun_service", wantErr: false},
+		{name: "compute node group", dirName: "google_compute_node_group", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -453,6 +459,7 @@ func TestTerraformStateReader_Azure_Resources(t *testing.T) {
 		{name: "private dns txt record", dirName: "azurerm_private_dns_txt_record", wantErr: false},
 		{name: "images", dirName: "azurerm_image", wantErr: false},
 		{name: "ssh public key", dirName: "azurerm_ssh_public_key", wantErr: false},
+		{name: "load balancer rule", dirName: "azurerm_lb_rule", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
