@@ -7,10 +7,10 @@ import (
 	"github.com/aws/aws-sdk-go/aws/awsutil"
 	"github.com/stretchr/testify/mock"
 
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	"github.com/cloudskiff/driftctl/pkg/resource/aws"
-	"github.com/cloudskiff/driftctl/pkg/terraform"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/pkg/terraform"
+	testresource "github.com/snyk/driftctl/test/resource"
 
 	"github.com/r3labs/diff/v2"
 )
