@@ -3,10 +3,13 @@ package aws_test
 import (
 	"testing"
 
-	"github.com/cloudskiff/driftctl/test"
-	"github.com/cloudskiff/driftctl/test/acceptance"
+	"github.com/snyk/driftctl/test"
+	"github.com/snyk/driftctl/test/acceptance"
 )
 
+// aws lambda list-event-source-mappings to list all event source mappings
+// aws lambda delete-event-source-mapping --uuid xxx to delete a specific event source mapping
+
 func TestAcc_AwsLambdaEventSourceMapping(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
