@@ -6,17 +6,17 @@ import (
 
 	"github.com/sirupsen/logrus"
 
-	"github.com/cloudskiff/driftctl/pkg/analyser"
-	awsresources "github.com/cloudskiff/driftctl/pkg/resource/aws"
-	"github.com/cloudskiff/driftctl/test"
+	"github.com/snyk/driftctl/pkg/analyser"
+	awsresources "github.com/snyk/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/test"
 
 	"github.com/r3labs/diff/v2"
 
 	"github.com/aws/aws-sdk-go/aws"
 
 	"github.com/aws/aws-sdk-go/service/sqs"
-	"github.com/cloudskiff/driftctl/test/acceptance"
-	"github.com/cloudskiff/driftctl/test/acceptance/awsutils"
+	"github.com/snyk/driftctl/test/acceptance"
+	"github.com/snyk/driftctl/test/acceptance/awsutils"
 )
 
 func TestAcc_AwsSQSQueue(t *testing.T) {
