@@ -83,8 +83,15 @@ func (r *Resource) SourceString() string {
 }
 
 func (r *Resource) Equal(res *Resource) bool {
-	return r.ResourceId() == res.ResourceId() &&
-		r.ResourceType() == res.ResourceType()
+	if r.ResourceId() != res.ResourceId() || r.ResourceType() != res.ResourceType() {
+		return false
+	}
+
+	if r.Schema() != nil && r.Schema().DiscriminantFunc != nil {
+		return r.Schema().DiscriminantFunc(r, res)
+	}
+
+	return true
 }
 
 type ResourceFactory interface {
@@ -311,3 +318,12 @@ func (a *Attributes) sanitize(path string, original, copy reflect.Value) bool {
 	}
 	return true
 }
+
+func FindCorrespondingRes(resources []*Resource, res *Resource) (int, *Resource, bool) {
+	for i, r := range resources {
+		if res.Equal(r) {
+			return i, r, true
+		}
+	}
+	return -1, nil, false
+}
